<?php

/**
 * @file
 * Provides Inline Conditions integration for the Commerce POS Discount module.
 */

/**
 * Implements hook_inline_conditions_info().
 */
function commerce_pos_discount_inline_conditions_info() {
  // User is order owner condition.
  $conditions['commerce_pos_discount_order_has_owner'] = [
    'label' => t('Order Owner'),
    'entity type' => 'commerce_order',
    'callbacks' => [
      'configure' => 'commerce_pos_discount_order_has_owner_configure',
    ],
  ];

  $conditions['commerce_pos_discount_product_has_owner'] = array(
    'label' => t('Order Owner'),
    'entity type' => 'commerce_line_item',
    'rule condition name' => 'data_is',
    'callbacks' => array(
      'configure' => 'commerce_pos_discount_product_has_owner_configure',
    ),
  );

  return $conditions;
}

/**
 * Inline conditions configure callback.
 *
 * Configure order has owner selection form.
 *
 * @param array $settings
 *   An array of rules condition settings.
 *
 * @return array
 *   Return a form build array.
 */
function commerce_pos_discount_order_has_owner_configure($settings) {
  $form = array();

  // Ensure we've default settings set.
  $settings += array(
    'account' => 0,
  );

  $form['account'] = array(
    '#type' => 'textfield',
    '#title' => t('Users'),
    '#title_display' => 'invisible',
    '#default_value' => ($account = user_load($settings['account'])) ? $account->name : '',
    '#required' => TRUE,
    '#autocomplete_path' => 'user/autocomplete',
    '#element_validate' => array('_commerce_pos_discount_order_has_owner_validate'),
    '#suffix' => '<div class="condition-instructions">' . t('Discount is active if the selected user is the owner of the order.') . '</div>',
  );

  return $form;
}

/**
 * Validation callback for a _commerce_pos_discount_order_has_owner_validate.
 */
function _commerce_pos_discount_order_has_owner_validate($element, &$form_state, $form) {
  // Try to fetch user.
  $user = user_load_by_name($element['#value']);

  if (!empty($user)) {
    $value = $user->uid;
    form_set_value($element, $value, $form_state);
  }
  else {
    form_set_error(implode('][', $element['#array_parents']), t('Enter a correct username.'));
  }
}

/**
 * Configuration callback for commerce_pos_discount_product_has_owner.
 *
 * @param array $settings
 *   An array of rules condition settings.
 *
 * @return array
 *   A form element array.
 */
function commerce_pos_discount_product_has_owner_configure($settings) {
  $form = array();

  // Ensure we've default settings set.
  $settings += array(
    'value' => 0,
  );

  // The bellow values (data:select & op) are added because they are required by
  // rule condition.
  $form['data:select'] = array(
    '#type' => 'textfield',
    '#access' => FALSE,
    '#default_value' => 'commerce-line-item:order:uid',
  );

  $form['op'] = array(
    '#type' => 'textfield',
    '#access' => FALSE,
    '#default_value' => '==',
  );

  $form['value'] = array(
    '#type' => 'textfield',
    '#title' => t('Users'),
    '#title_display' => 'invisible',
    '#default_value' => isset($settings['value']) ? user_load($settings['value'])->name : '',
    '#required' => TRUE,
    '#autocomplete_path' => 'user/autocomplete',
    '#element_validate' => array('_commerce_pos_discount_order_has_owner_validate'),
    '#suffix' => '<div class="condition-instructions">' . t('Discount is active if the selected user is the owner of the order.') . '</div>',
  );

  return $form;
}
